==> haskell-bytestring-tree-builder-0.2.7.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.1
id: bytestring-tree-builder-0.2.7.1-IDYCLeHTgnPLwwsmO6qGpJ
key: bytestring-tree-builder-0.2.7.1-IDYCLeHTgnPLwwsmO6qGpJ
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
abi: ff51f554d376a5f4dec13f7a290d541c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-tree-builder-0.2.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-tree-builder-0.2.7.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/bytestring-tree-builder-0.2.7.1
hs-libraries: HSbytestring-tree-builder-0.2.7.1-IDYCLeHTgnPLwwsmO6qGpJ
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1 semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-tree-builder
version: 0.2.7.1
id: bytestring-tree-builder-0.2.7.1-E2ysOXo3HB01TL1PzBXA2X
key: bytestring-tree-builder-0.2.7.1-E2ysOXo3HB01TL1PzBXA2X
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-tree-builder
synopsis: A very efficient ByteString builder implementation based on the binary tree
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.
category: ByteString
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    ByteString.TreeBuilder
hidden-modules: ByteString.TreeBuilder.Prelude
                ByteString.TreeBuilder.Poker ByteString.TreeBuilder.Tree
abi: b51d9fc7e2171993b6e12f4257fe902d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-tree-builder-0.2.7.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/bytestring-tree-builder-0.2.7.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/bytestring-tree-builder-0.2.7.1
hs-libraries: HSbytestring-tree-builder-0.2.7.1-E2ysOXo3HB01TL1PzBXA2X
depends:
    base-4.9.0.0 base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    bytestring-0.10.8.1 semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
